% Destabilizing evolutionary and eco-evolutionary feedbacks drive eco-evo cycles in empirical systems. 
% Michael H. Cortez, Swati Patel, Sebastian J. Schreiber
% Proceedings B of the Royal Society: Biological Sciences
% DOI: 10.1098/rspb.2019.2298

% Computes long-term values for Becks et al. model at varying evolutionary speeds

clear all

% Parameter Values
    p1 = .1;
    p2 = 1;
    Ni = 160;
    delta = .3;
    m = 0.55e-1;
    lambda = .4;
    Xc = 0.27e-2;
    Kc1 = 8-5.8*p1;
    Kc2 = 2.2;
    rho = 270;
    Xb = 170;
    Kb = .15;
    G = 0.11e-1;
    

% Evolutionary speeds - stable for epsilon<0.6274
epsilon = 0.63:0.01:2;

minxval = zeros(1,length(epsilon));
maxxval = zeros(1,length(epsilon));
minyval = zeros(1,length(epsilon));
maxyval = zeros(1,length(epsilon));
minaval = zeros(1,length(epsilon));
maxaval = zeros(1,length(epsilon));

for ii = 1:length(epsilon)

para=[p1 p2 Ni delta m lambda Xc Kc1 Kc2 rho Xb Kb G epsilon(ii)]; 
t_max = 1000;    
startx=[6 0.3 2.5 2.8 0.7];
tspan = [0 t_max];
options = odeset('RelTol',10^-12);
tfinal = []; resfinal =[];
[tfinal,resfinal] = ode23s(@BecksModel_Equations,tspan,startx,options,para);

tspan = [0 100];
startx = resfinal(end,:);
[tfinal,resfinal] = ode23s(@BecksModel_Equations,tspan,startx,options,para);

minxval(ii) = min(resfinal(:,2));
maxxval(ii) = max(resfinal(:,2));
minyval(ii) = min(resfinal(:,3)+resfinal(:,4));
maxyval(ii) = max(resfinal(:,3)+resfinal(:,4));
minaval(ii) = min(resfinal(:,5));
maxaval(ii) = max(resfinal(:,5));
end

Data = [epsilon; minxval; maxxval; minyval; maxyval; minaval; maxaval];
csvwrite('BecksModel.dat',Data)

