% Destabilizing evolutionary and eco-evolutionary feedbacks drive eco-evo cycles in empirical systems. 
% Michael H. Cortez, Swati Patel, Sebastian J. Schreiber
% Proceedings B of the Royal Society: Biological Sciences
% DOI: 10.1098/rspb.2019.2298

% Computes long-term values for Duffy et al. model at varying evolutionary speeds

clear all

% Parameter Values
    beta1 = .5*10^(-6);  
    beta2 = 8.5*10^(-6);  
    b1 = 5712.11*beta1+.241;
    b2 = 5712.11*beta2+.241; 
    d = 0.5e-1;  
    ee = .5;  
    f = .75;  
    K = 5;  
    m = .1;  
    n = 0.5e-1;  
    v = 0.5e-1;  
    theta = 9; 
    sigma = 15000;
    

% Evolutionary speeds - stable for epsilon<18.05 and epsilon>687.7
epsilon = [18.1:0.1:19 20:20:680 681:1:687 687.1:0.1:687.7];

% Maximum and minimum values for cycles
minxval = zeros(1,length(epsilon));
maxxval = zeros(1,length(epsilon));
minyval = zeros(1,length(epsilon));
maxyval = zeros(1,length(epsilon));
minzval = zeros(1,length(epsilon));
maxzval = zeros(1,length(epsilon));
minaval = zeros(1,length(epsilon));
maxaval = zeros(1,length(epsilon));
minbval = zeros(1,length(epsilon));
maxbval = zeros(1,length(epsilon));

% Simulate model for each value of epsilon
for ii = 1:length(epsilon)

% Parameters
para=[beta1 beta2 b1 b2 d ee f K m n v theta sigma epsilon(ii)]; 

% Simulation parameters
t_max = 1600;    
startx=[1.8 .02 4000 0.65 0.1];
tspan = [0 t_max];
options = odeset('RelTol',10^-12);

% Simulate model 
tfinal = []; resfinal =[];
[tfinal,resfinal] = ode23s(@DuffyModel_Equations,tspan,startx,options,para);

tspan = [0 100];
startx = resfinal(end,:);
[tfinal,resfinal] = ode23s(@DuffyModel_Equations,tspan,startx,options,para);

% Save maximum and minimum values for cycles
minxval(ii) = min(resfinal(:,1));
maxxval(ii) = max(resfinal(:,1));
minyval(ii) = min(resfinal(:,2));
maxyval(ii) = max(resfinal(:,2));
minzval(ii) = min(resfinal(:,3));
maxzval(ii) = max(resfinal(:,3));
minaval(ii) = min(resfinal(:,4));
maxaval(ii) = max(resfinal(:,4));
minbval(ii) = min(resfinal(:,5));
maxbval(ii) = max(resfinal(:,5));
end

% Export saved values
Data = [epsilon; minxval; maxxval; minyval; maxyval; minzval; maxzval; minaval; maxaval; minbval; maxbval];
csvwrite('DuffyModel.dat',Data)

