#Destabilizing evolutionary and eco-evolutionary feedbacks drive eco-evo cycles in empirical systems. 
#Michael H. Cortez, Swati Patel, Sebastian J. Schreiber
#Proceedings B of the Royal Society: Biological Sciences
#DOI: 10.1098/rspb.2019.2298

## This script computes the stabilities of subsystems

library(rootSolve)
library(numDeriv)
# the following function solves for the equilibrium
# computes the jacobian matrix and returns both as a list
eqJac=function(xstart,f){
xstar=multiroot(f,start=xstart)$root
df=jacobian(f,xstar)
return(list(x=xstar,df=df))}

# computes the stability modulus
# of J, J restricted to the indices
# given by S, and J restricted to 
# the complementary indices of S
knockout.complements=function(J,S){
  k=dim(J)[1]
  A=J[S,S]
  Sc=setdiff(1:k,S)
  B=J[Sc,Sc]
  sA=max(Re(eigen(A)$values))
  sB=max(Re(eigen(B)$values))
  sJ=max(Re(eigen(J)$values))
  return(c(sJ,sA,sB))
}


# The following function computes the stability modulus of the matrix J
# Then removes every possible subsystem and records which of these
# removals change the sign of the stability modulus
# It returns the list of sign changing subsystems, the stability modulus s of 
# the original matrix J, and the total number of strict subsystems

knockout.all=function(J){
  k=dim(J)[1]-1
  change=list()
  counter=0
  s=max(Re(eigen(J)$values))
  total=0
  for(i in 1:k){
    subsystems=combn(k+1,i)
    k2=length(subsystems[1,])
    total=total+k2
    for(i2 in 1:k2){
      Jtemp=J[-subsystems[,i2],-subsystems[,i2]]
      stemp=max(Re(eigen(Jtemp)$values))
      if(sign(stemp)!=sign(s)){
        counter=counter+1
        change[[counter]]=subsystems[,i2]
      }
    }
  }
  return(list(change=change,s=s,total=total))
}

# the following function finds the minimal 
# subsystems that change stability of the full system

minimal.subsets=function(change){
  len=length(change)
  sizes=numeric(len)
  for(i in 1:len)sizes[i]=length(change[[i]])
  who.is.minimal=which(sizes==sizes[1])
  i1=max(who.is.minimal)+1
  for(i in i1:len){
    proper=TRUE
    who.to.check=which(sizes<sizes[i])
    for(j in 1:length(who.to.check)){
      if(all(change[[who.to.check[j]]]%in%change[[i]]))proper=FALSE
    }
    if(proper)who.is.minimal=c(who.is.minimal,i)
  }
  wm=list()
  for(i in 1:length(who.is.minimal))wm[[i]]=change[[who.is.minimal[i]]]
  return(wm)
}
