#############################################
### Duffy et al. 2012
#############################################

### CLONAL MODEL - S1, S2, II1, II2, Z
#eqn1 = b1*(II1*f+S1)*(1-(S1+S2+II1+II2)/K)-n*S1-m*S1-beta1*S1*Z
#eqn2 = b2*(II2*f+S2)*(1-(S1+S2+II1+II2)/K)-n*S2-m*S2-beta2*S2*Z
#eqn3 = -II1*m*theta+S1*Z*beta1-II1*n-II1*v
#eqn4 = -II2*m*theta+S2*Z*beta2-II2*n-II2*v
#eqn5 = sigma*(e*m*theta+n+v)*(II1+II2)-d*Z-beta1*S1*Z-beta2*S2*Z

### Parameters
beta1 = .5*10^(-6)
beta2 = 8.5*10^(-6)
b1 = 5712.11*beta1+.241
b2 = 5712.11*beta2+.241
d = 0.5e-1
e = .5
f = .75
K = 5
m = .1
n = 0.5e-1
v = 0.5e-1
theta = 9
sigma = 15000

### CONTINUOUS TRAIT MODEL - S = S1+S2, II = II1+II2,Z, alpha = S1/(S1+S2), beta = II1/(II1+II2)

f2=function(x){S=x[1];II=x[2];Z=x[3];alpha=x[4];beta=x[5];
eqn1 = b1*(II*beta*f+S*alpha)*(1-(II+S)/K)-n*alpha*S-m*alpha*S-beta1*alpha*S*Z+b2*((-II*beta+II)*f-alpha*S+S)*(1-(II+S)/K)-n*(-S*alpha+S)-m*(-S*alpha+S)-beta2*(-S*alpha+S)*Z;
eqn2 = -beta*II*m*theta-(-II*beta+II)*m*theta+beta1*alpha*S*Z+beta2*(-S*alpha+S)*Z-beta*II*n-beta*II*v-(-II*beta+II)*n-(-II*beta+II)*v;
eqn3 = sigma*(e*m*theta+n+v)*II-d*Z-beta1*alpha*S*Z-beta2*(-S*alpha+S)*Z;
eqn4 = ((b1*(II*beta*f+S*alpha)*(1-(II+S)/K)-n*alpha*S-m*alpha*S-beta1*alpha*S*Z)*S-alpha*S*(b1*(II*beta*f+S*alpha)*(1-(II+S)/K)-n*alpha*S-m*alpha*S-beta1*alpha*S*Z+b2*((-II*beta+II)*f-alpha*S+S)*(1-(II+S)/K)-n*(-S*alpha+S)-m*(-S*alpha+S)-beta2*(-S*alpha+S)*Z))/S^2;
eqn5 = ((-II*beta*m*theta+S*Z*alpha*beta1-II*beta*n-II*beta*v)*II-beta*II*(-beta*II*m*theta-(-II*beta+II)*m*theta+beta1*alpha*S*Z+beta2*(-S*alpha+S)*Z-beta*II*n-beta*II*v-(-II*beta+II)*n-(-II*beta+II)*v))/II^2;
return(c(eqn1,eqn2,eqn3,eqn4, eqn5))}

# Initial Guess for Equilibrium
### Equilibrium point
xstart=c(1.8,0.025,4000,0.6,0.1)
