#############################################
### Frickel et al. 2016
#############################################

### CLONAL MODEL - S, B1, B2, B3, B4, P1, P2, P3

#eqn1 = DD*(S0-S)-c*(B1*a1*S/(H+S)+B2*((1/3)*aN+(2/3)*a1)*S/(H+S)+B3*((2/3)*aN+(1/3)*a1)*S/(H+S)+B4*aN*S/(H+S))
#eqn2 = (1-epsilon)*a1*S*B1/(H+S)+(1/2)*epsilon*((1/3)*aN+(2/3)*a1)*S*B2/(H+S)-phi*(P1+P2+P3)*B1-DD*B1
#eqn3 = epsilon*a1*S*B1/(H+S)+(1-epsilon)*((1/3)*aN+(2/3)*a1)*S*B2/(H+S)+(1/2)*epsilon*((2/3)*aN+(1/3)*a1)*S*B3/(H+S)-phi*(P2+P3)*B2-DD*B2
#eqn4 = (1/2)*epsilon*((1/3)*aN+(2/3)*a1)*S*B2/(H+S)+(1-epsilon)*((2/3)*aN+(1/3)*a1)*S*B3/(H+S)+epsilon*aN*S*B4/(H+S)-phi*P3*B3-DD*B3
#eqn5 = (1/2)*epsilon*((2/3)*aN+(1/3)*a1)*S*B3/(H+S)+(1-epsilon)*aN*S*B4/(H+S)-DD*B4
#eqn6 = (1-epsilon)*beta*phi*B1*P1+(1/2)*epsilon*beta*phi*(B1+B2)*P2-phi*B1*P1-DD*P1
#eqn7 = epsilon*beta*phi*B1*P1+(1-epsilon)*beta*phi*(B1+B2)*P2+epsilon*beta*phi*(B1+B2+B3)*P3-phi*(B1+B2)*P2-DD*P2
#eqn8 = (1/2)*epsilon*beta*phi*(B1+B2)*P2+(1-epsilon)*beta*phi*(B1+B2+B3)*P3-phi*(B1+B2+B3)*P3-DD*P3

### Parameters
aN = .15
DD = .1
S0 = 30
a1 = .25
H = 1
c = 0.2300000000e-4
phi = 7.500000000*10^(-8)
beta = 100
epsilon = 1/1000

### CONTINUOUS TRAIT MODEL - S, B = B1+B2+B3+B4, P = P1+P2+P3, alpha1 = B1/B, alpha2 = B2/B, alpha3 = B3/B, beta1 = P1/P, beta2 = P2/P

f=function(x){S=x[1];B=x[2];P=x[3];alpha1=x[4];alpha2=x[5];alpha3=x[6];beta1=x[7];beta2=x[8];
eqn1= DD*(S0-S)-c*(alpha1*B*a1*S/(H+S)+alpha2*B*((1/3)*aN+(2/3)*a1)*S/(H+S)+alpha3*B*((2/3)*aN+(1/3)*a1)*S/(H+S)+(-B*alpha1-B*alpha2-B*alpha3+B)*aN*S/(H+S));
eqn2= (1-epsilon)*a1*S*alpha1*B/(H+S)+epsilon*((1/3)*aN+(2/3)*a1)*S*alpha2*B/(H+S)-phi*P*alpha1*B-DD*alpha1*B+epsilon*a1*S*alpha1*B/(H+S)+(1-epsilon)*((1/3)*aN+(2/3)*a1)*S*alpha2*B/(H+S)+epsilon*((2/3)*aN+(1/3)*a1)*S*alpha3*B/(H+S)-phi*(-P*beta1+P)*alpha2*B-DD*alpha2*B+(1-epsilon)*((2/3)*aN+(1/3)*a1)*S*alpha3*B/(H+S)+epsilon*aN*S*(-B*alpha1-B*alpha2-B*alpha3+B)/(H+S)-phi*(-P*beta1-P*beta2+P)*alpha3*B-DD*alpha3*B+(1-epsilon)*aN*S*(-B*alpha1-B*alpha2-B*alpha3+B)/(H+S)-DD*(-B*alpha1-B*alpha2-B*alpha3+B);
eqn3= (1-epsilon)*beta*phi*alpha1*B*beta1*P+epsilon*beta*phi*(B*alpha1+B*alpha2)*beta2*P-phi*alpha1*B*beta1*P-DD*beta1*P+epsilon*beta*phi*alpha1*B*beta1*P+(1-epsilon)*beta*phi*(B*alpha1+B*alpha2)*beta2*P+epsilon*beta*phi*(B*alpha1+B*alpha2+B*alpha3)*(-P*beta1-P*beta2+P)-phi*(B*alpha1+B*alpha2)*beta2*P-DD*beta2*P+(1-epsilon)*beta*phi*(B*alpha1+B*alpha2+B*alpha3)*(-P*beta1-P*beta2+P)-phi*(B*alpha1+B*alpha2+B*alpha3)*(-P*beta1-P*beta2+P)-DD*(-P*beta1-P*beta2+P);
eqn4= (((1-epsilon)*a1*S*alpha1*B/(H+S)+(1/2)*epsilon*((1/3)*aN+(2/3)*a1)*S*alpha2*B/(H+S)-phi*P*alpha1*B-DD*alpha1*B)*B-alpha1*B*((1-epsilon)*a1*S*alpha1*B/(H+S)+epsilon*((1/3)*aN+(2/3)*a1)*S*alpha2*B/(H+S)-phi*P*alpha1*B-DD*alpha1*B+epsilon*a1*S*alpha1*B/(H+S)+(1-epsilon)*((1/3)*aN+(2/3)*a1)*S*alpha2*B/(H+S)+epsilon*((2/3)*aN+(1/3)*a1)*S*alpha3*B/(H+S)-phi*(-P*beta1+P)*alpha2*B-DD*alpha2*B+(1-epsilon)*((2/3)*aN+(1/3)*a1)*S*alpha3*B/(H+S)+epsilon*aN*S*(-B*alpha1-B*alpha2-B*alpha3+B)/(H+S)-phi*(-P*beta1-P*beta2+P)*alpha3*B-DD*alpha3*B+(1-epsilon)*aN*S*(-B*alpha1-B*alpha2-B*alpha3+B)/(H+S)-DD*(-B*alpha1-B*alpha2-B*alpha3+B)))/B^2;
eqn5= ((epsilon*a1*S*alpha1*B/(H+S)+(1-epsilon)*((1/3)*aN+(2/3)*a1)*S*alpha2*B/(H+S)+(1/2)*epsilon*((2/3)*aN+(1/3)*a1)*S*alpha3*B/(H+S)-phi*(-P*beta1+P)*alpha2*B-DD*alpha2*B)*B-alpha2*B*((1-epsilon)*a1*S*alpha1*B/(H+S)+epsilon*((1/3)*aN+(2/3)*a1)*S*alpha2*B/(H+S)-phi*P*alpha1*B-DD*alpha1*B+epsilon*a1*S*alpha1*B/(H+S)+(1-epsilon)*((1/3)*aN+(2/3)*a1)*S*alpha2*B/(H+S)+epsilon*((2/3)*aN+(1/3)*a1)*S*alpha3*B/(H+S)-phi*(-P*beta1+P)*alpha2*B-DD*alpha2*B+(1-epsilon)*((2/3)*aN+(1/3)*a1)*S*alpha3*B/(H+S)+epsilon*aN*S*(-B*alpha1-B*alpha2-B*alpha3+B)/(H+S)-phi*(-P*beta1-P*beta2+P)*alpha3*B-DD*alpha3*B+(1-epsilon)*aN*S*(-B*alpha1-B*alpha2-B*alpha3+B)/(H+S)-DD*(-B*alpha1-B*alpha2-B*alpha3+B)))/B^2;
eqn6= (((1/2)*epsilon*((1/3)*aN+(2/3)*a1)*S*alpha2*B/(H+S)+(1-epsilon)*((2/3)*aN+(1/3)*a1)*S*alpha3*B/(H+S)+epsilon*aN*S*(-B*alpha1-B*alpha2-B*alpha3+B)/(H+S)-phi*(-P*beta1-P*beta2+P)*alpha3*B-DD*alpha3*B)*B-alpha3*B*((1-epsilon)*a1*S*alpha1*B/(H+S)+epsilon*((1/3)*aN+(2/3)*a1)*S*alpha2*B/(H+S)-phi*P*alpha1*B-DD*alpha1*B+epsilon*a1*S*alpha1*B/(H+S)+(1-epsilon)*((1/3)*aN+(2/3)*a1)*S*alpha2*B/(H+S)+epsilon*((2/3)*aN+(1/3)*a1)*S*alpha3*B/(H+S)-phi*(-P*beta1+P)*alpha2*B-DD*alpha2*B+(1-epsilon)*((2/3)*aN+(1/3)*a1)*S*alpha3*B/(H+S)+epsilon*aN*S*(-B*alpha1-B*alpha2-B*alpha3+B)/(H+S)-phi*(-P*beta1-P*beta2+P)*alpha3*B-DD*alpha3*B+(1-epsilon)*aN*S*(-B*alpha1-B*alpha2-B*alpha3+B)/(H+S)-DD*(-B*alpha1-B*alpha2-B*alpha3+B)))/B^2;
eqn7= (((1-epsilon)*beta*phi*alpha1*B*beta1*P+(1/2)*epsilon*beta*phi*(B*alpha1+B*alpha2)*beta2*P-phi*alpha1*B*beta1*P-DD*beta1*P)*P-beta1*P*((1-epsilon)*beta*phi*alpha1*B*beta1*P+epsilon*beta*phi*(B*alpha1+B*alpha2)*beta2*P-phi*alpha1*B*beta1*P-DD*beta1*P+epsilon*beta*phi*alpha1*B*beta1*P+(1-epsilon)*beta*phi*(B*alpha1+B*alpha2)*beta2*P+epsilon*beta*phi*(B*alpha1+B*alpha2+B*alpha3)*(-P*beta1-P*beta2+P)-phi*(B*alpha1+B*alpha2)*beta2*P-DD*beta2*P+(1-epsilon)*beta*phi*(B*alpha1+B*alpha2+B*alpha3)*(-P*beta1-P*beta2+P)-phi*(B*alpha1+B*alpha2+B*alpha3)*(-P*beta1-P*beta2+P)-DD*(-P*beta1-P*beta2+P)))/P^2;
eqn8= ((epsilon*beta*phi*alpha1*B*beta1*P+(1-epsilon)*beta*phi*(B*alpha1+B*alpha2)*beta2*P+epsilon*beta*phi*(B*alpha1+B*alpha2+B*alpha3)*(-P*beta1-P*beta2+P)-phi*(B*alpha1+B*alpha2)*beta2*P-DD*beta2*P)*P-beta2*P*((1-epsilon)*beta*phi*alpha1*B*beta1*P+epsilon*beta*phi*(B*alpha1+B*alpha2)*beta2*P-phi*alpha1*B*beta1*P-DD*beta1*P+epsilon*beta*phi*alpha1*B*beta1*P+(1-epsilon)*beta*phi*(B*alpha1+B*alpha2)*beta2*P+epsilon*beta*phi*(B*alpha1+B*alpha2+B*alpha3)*(-P*beta1-P*beta2+P)-phi*(B*alpha1+B*alpha2)*beta2*P-DD*beta2*P+(1-epsilon)*beta*phi*(B*alpha1+B*alpha2+B*alpha3)*(-P*beta1-P*beta2+P)-phi*(B*alpha1+B*alpha2+B*alpha3)*(-P*beta1-P*beta2+P)-DD*(-P*beta1-P*beta2+P)))/P^2;
return(c(eqn1,eqn2,eqn3,eqn4, eqn5,eqn6,eqn7,eqn8))}

# Initial Guess for Equilibrium
### Equilibrium point
xstart=c(2.006009683, 1.208151290*10^6, 8.888937140*10^5, 0.8842229693e-2, 0.7256068526e-4, 0.2244080213e-2, 0.9732493010e-5, 0.5002674188e-2)


