#Destabilizing evolutionary and eco-evolutionary feedbacks drive eco-evo cycles in empirical systems. 
#Michael H. Cortez, Swati Patel, Sebastian J. Schreiber
#Proceedings B of the Royal Society: Biological Sciences
#DOI: 10.1098/rspb.2019.2298

## This code uses Base-Simple.R to compute the stabilities of the subsystems for each model. 
## Models and parameters are given in accompanying files. 
## Small numerical errors that arise are stated below.  

# load the functions

setwd("") # change me! 

source("Base-Simple.R")

###########
# Becks et al. (2010).
###########
# load the model and the initial guess for the equilibrium
source("Becks.R")
# compute jacobian and equilibrium
out=eqJac(xstart,f)
eq=out$x
df=out$df#
# system unstable
# eco-evo decomposition = prey evo decomposition
knockout.complements(df,S=1:4) # S/U
# prey eco decomposition
knockout.complements(df,S=c(2,5)) #U/S. Numerical error - should be S/NS
# pred eco decomposition
knockout.complements(df,S=3:4) #U/U. Numerical error - should be NS-U

###########
# Boker - SARS
###########
# load the models and the initial guesses for the equilibria
source("Bolker_SARS.R")
# SARS Parameters 
# compute jacobian and equilibrium
out=eqJac(xstart1,f1)
eq=out$x
df=out$df
# system stable
# eco-evo decomposition = pathogen evo decomposition
knockout.complements(df,S=1:2) # S/S
# pathogen eco-evo decomposition = host eco decomposiion
knockout.complements(df,S=c(2,3)) #U/S. Numerical error - should be NS/S

###########
# Boker - HIV
###########
# load the models and the initial guesses for the equilibria
source("Bolker_HIV.R")
# SARS Parameters 
# compute jacobian and equilibrium
out=eqJac(xstart2,f2)
eq=out$x
df=out$df
# system stable
# eco-evo decomposition = pathogen evo decomposition
knockout.complements(df,S=1:2) # S/S
# pathogen eco-evo decomposition = host eco decomposiion
knockout.complements(df,S=c(2,3)) #U/S. Numerical error - should be NS/S

###########
# Boker - WNV
###########
# load the models and the initial guesses for the equilibria
source("Bolker_WNV.R")
# SARS Parameters 
# compute jacobian and equilibrium
out=eqJac(xstart3,f3)
eq=out$x
df=out$df
# system stable
# eco-evo decomposition = pathogen evo decomposition
knockout.complements(df,S=1:2) # S/S
# pathogen eco-evo decomposition = host eco decomposiion
knockout.complements(df,S=c(2,3)) #S/S. Numerical error - should be NS/S

###########
# Boker - Myxomatosis
###########
# load the models and the initial guesses for the equilibria
source("Bolker_Myx.R")
# SARS Parameters 
# compute jacobian and equilibrium
out=eqJac(xstart4,f4)
eq=out$x
df=out$df
# system stable
# eco-evo decomposition = pathogen evo decomposition
knockout.complements(df,S=1:2) # S/S
# pathogen eco-evo decomposition = host eco decomposiion
knockout.complements(df,S=c(2,3)) #S/S. Numerical error - should be NS/S



###########
# Duffy et al. (2012).
###########
# load the model and the initial guess for the equilibrium
source("Duffy.R")

# compute jacobian and equilibrium
out=eqJac(xstart,f2)
eq=out$x
df=out$df
# system is stable 
# eco-evo decomposition & host evo
knockout.complements(df,S=1:3) #S/S
# host eco-evo decomposition
knockout.complements(df,S=c(1,2,4,5)) #U/S. Numerical error - should be S/S
# pathogen (spore+infected) eco decomposition
knockout.complements(df,S=c(2,3)) #U/S


###########
# Frickel et al. (2016).
###########

# load the model and the initial guess for the equilibrium

source("Frickel.R")

# compute jacobian and equilibrium
out=eqJac(xstart,f)
eq=out$x
df=out$df
# system unstable
# eco-evo decomposition 
knockout.complements(df,S=1:3) # S/S
# prey evo decomposition
knockout.complements(df,S=4:6) # S/S
# prey eco-evo decomposition
knockout.complements(df,S=c(2,4,5,6)) # U/S - Numerical error - should be NS/NS
# pred evo decomposition
knockout.complements(df,S=c(7,8)) #S/S
# pred eco-evo decomposition
knockout.complements(df,S=c(3,7,8)) # S/S - Numerical error - should be NS/S



###########
# Haafke et al. (2016).
###########

# load the model and the initial guess for the equilibrium

source("Haafke.R")

# compute jacobian and equilibrium
out=eqJac(xstart,f)
eq=out$x
df=out$df
# system unstable
# eco-evo decomposition = prey evo decomposition
knockout.complements(df,S=1:4) # U/U
# prey evo decomposition
knockout.complements(df,S=5) # U/U
# prey eco-evo decomposition
knockout.complements(df,S=c(2,5)) #U/N
# pred evo decomposition
knockout.complements(df,S=c(6,7)) #N/U
# pred eco-evo decomposition
knockout.complements(df,S=c(3,4,6,7)) #N/U


###########
# Hiltunen et al. (2014)
###########
# Figure 1B
###########
# load the model and the initial guess for the equilibrium
source("Hiltunen1B.R")

# compute jacobian and equilibrium
out=eqJac(xstart,f)
eq=out$x
df=out$df
# system unstable
# eco-evo decomposition = prey evo decomposition
knockout.complements(df,S=1:4) # S/U
# prey evo decomposition
knockout.complements(df,S=5) # U/S
# prey eco-evo decomposition
knockout.complements(df,S=c(2,5)) #U/S
# pred eco-evo decomposition
knockout.complements(df,S=c(3,4)) #S/U
###########
# Figure 1C
###########
# load the model and the initial guess for the equilibrium
source("Hiltunen1C.R")
# compute jacobian and equilibrium
out=eqJac(xstart,f)
eq=out$x
df=out$df
# system is unstable
# eco-evo decomposition = prey evo decomposition
knockout.complements(df,S=1:4) # S/U
# prey evo decomposition
knockout.complements(df,S=5) # U/S
# prey eco-evo decomposition
knockout.complements(df,S=c(2,5)) #U/U
# pred eco-evo decomposition
knockout.complements(df,S=c(3,4)) #U/U
###########
# Figure 1D
###########
# load the model and the initial guess for the equilibrium
source("Hiltunen1D.R")
# compute jacobian and equilibrium
out=eqJac(xstart,f)
eq=out$x  
df=out$df
# system unstable
# eco-evo decomposition = prey evo decomposition
knockout.complements(df,S=1:4) # S/U
# prey evo decomposition
knockout.complements(df,S=5) # U/S
# prey eco-evo decomposition
knockout.complements(df,S=c(2,5)) #U/S
# pred eco-evo decomposition
knockout.complements(df,S=c(3,4)) #S/U


###########
# Kasada et al. (2014).
###########

# load the model and the initial guess for the equilibrium

source("Kasada.R")

# compute jacobian and equilibrium
out=eqJac(xstart,f)
eq=out$x
df=out$df
# system is stable
# eco-evo decomposition = prey evo decomposition
knockout.complements(df,S=1:3) # S/U
# prey evo decomposition
knockout.complements(df,S=4) # U/S
# prey eco-evo decomposition
knockout.complements(df,S=c(2,4)) #U/S. Numerical Error - should be U/NS
# pred eco-evo decomposition
knockout.complements(df,S=3) #S/U. Numerical Error - should be N/U

###########
# Wei et al. Figure 5a
###########

# load the model and the initial guess for the equilibrium

source("Wei5a.R")

# compute jacobian and equilibrium
out=eqJac(xstart,f)
eq=out$x
df=out$df
# system is stable
# eco-evo decomposition = prey evo decomposition
knockout.complements(df,S=1:5) # S/S
# prey evo decomposition
knockout.complements(df,S=6:8) # S/N
# prey eco-evo decomposition
knockout.complements(df,S=c(2:4,6:8)) #U/N. Numerical Error - should be S/NS
# pred evo decomposition
knockout.complements(df,S=9) #N/S
# pred eco-evo decomposition
knockout.complements(df,S=c(5,9)) #N/S

###########
# Wei et al. Figure 5b
###########
# load the model and the initial guess for the equilibrium
source("Wei5b.R")
# compute jacobian and equilibrium
out=eqJac(xstart,f)
eq=out$x
df=out$df
# system is stable
# eco-evo decomposition = prey evo decomposition
knockout.complements(df,S=1:5) # S/S
# prey evo decomposition
knockout.complements(df,S=6:9) # S/U
# prey eco-evo decomposition
knockout.complements(df,S=c(2:4,6:9)) #U/S. Numerical Error - should be U/NS
# pred evo decomposition
knockout.complements(df,S=10) #S/S. Numerical Error - should be N/S
# pred eco-evo decomposition
knockout.complements(df,S=c(5,10)) #S/U. Numerical Error - should be N/U




###########
# Yoshida et al. (2003,2007).
###########

# load the model and the initial guess for the equilibrium

source("Yoshida.R")

# compute jacobian and equilibrium
out=eqJac(xstart,f)
eq=out$x
df=out$df
# system is unstable
# eco-evo decomposition = prey evo decomposition
knockout.complements(df,S=1:4) #S/U
# prey eco decomposition
knockout.complements(df,S=c(2,5)) #U/S. Numerical error - should be U,NS
# pred eco decomposition
knockout.complements(df,S=3:4) #S/U. Numerical error - should be N/U




