#############################################
### Yoshida et al. 2003, 2007
#############################################

### CLONAL MODEL - N, C1, C2, B, R

#eqn1 = delta*(Ni*V-N)-omegac*betac*N*C1/(epsilonc*V*(Kc1+N/V))-omegac*betac*N*C2/(epsilonc*V*(Kc2+N/V))
#eqn2 = C1*(-B*p1*G/(C1*p1+C2*p2+Kb)+omegac*betac*N*Xic/(epsilonc*V*(Kc1+N/V))-delta)
#eqn3 = C2*(-B*p2*G/(C1*p1+C2*p2+Kb)+omegac*betac*N*Xic/(epsilonc*V*(Kc2+N/V))-delta)
#eqn4 = Xib*(C1*p1+C2*p2)*G*R/(C1*p1+C2*p2+Kb)-(delta+m)*B
#eqn5 = Xib*(C1*p1+C2*p2)*G*R/(C1*p1+C2*p2+Kb)-(delta+m+lambda)*R

### Parameters
Ni = 80
V = .33 
Kmin = 4.3
Kb = .292
betac = 3.3
alpha1 = 1.9
alpha2 = 4.0
pmin = 0.2e-1
delta = .69
Xib = 5400
Xic = 0.5e-1
omegac = 20
epsilonc = 1
G = 3.3*10^(-4)
lambda = .4
m = 0.55e-1
p1 = 0.2e-1
p2 = .95
Kc1 = Kmin+alpha2*(1-p1^alpha1)^(1/alpha1)
Kc2 = Kmin+alpha2*(1-p2^alpha1)^(1/alpha1)


### CONTINUOUS TRAIT MODEL - N, C = C1+C2, B, R, alpha = C1/C

f=function(x){N=x[1];C=x[2];B=x[3];R=x[4];alpha=x[5];
eqn1= delta*(Ni*V-N)-omegac*betac*N*alpha*C/(epsilonc*V*(Kc1+N/V))-omegac*betac*N*(-C*alpha+C)/(epsilonc*V*(Kc2+N/V));
eqn2= alpha*C*(-B*p1*G/(p1*alpha*C+p2*(-C*alpha+C)+Kb)+omegac*betac*N*Xic/(epsilonc*V*(Kc1+N/V))-delta)+(-C*alpha+C)*(-B*p2*G/(p1*alpha*C+p2*(-C*alpha+C)+Kb)+omegac*betac*N*Xic/(epsilonc*V*(Kc2+N/V))-delta);
eqn3= Xib*(p1*alpha*C+p2*(-C*alpha+C))*G*R/(p1*alpha*C+p2*(-C*alpha+C)+Kb)-(delta+m)*B;
eqn4= Xib*(p1*alpha*C+p2*(-C*alpha+C))*G*R/(p1*alpha*C+p2*(-C*alpha+C)+Kb)-(delta+m+lambda)*R;
eqn5= (alpha*C^2*(-B*p1*G/(p1*alpha*C+p2*(-C*alpha+C)+Kb)+omegac*betac*N*Xic/(epsilonc*V*(Kc1+N/V))-delta)-alpha*C*(alpha*C*(-B*p1*G/(p1*alpha*C+p2*(-C*alpha+C)+Kb)+omegac*betac*N*Xic/(epsilonc*V*(Kc1+N/V))-delta)+(-C*alpha+C)*(-B*p2*G/(p1*alpha*C+p2*(-C*alpha+C)+Kb)+omegac*betac*N*Xic/(epsilonc*V*(Kc2+N/V))-delta)))/C^2;
return(c(eqn1,eqn2,eqn3,eqn4, eqn5))}

# Initial Guess for Equilibrium
xstart=c(0.7,1,700,450,0.5)